#
# spec file for package opencl-headers
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opencl-headers
Version:        2024.10.24
Release:        1.1
Summary:        OpenCL (Open Computing Language) headers
License:        MIT
URL:            https://www.khronos.org/registry/cl/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  python3-base
Conflicts:      opencl-headers-1_2
BuildArch:      noarch

%description
OpenCL is a royalty-free standard for cross-platform, parallel programming
of modern processors found in personal computers, servers and
handheld/embedded devices.

This package provides the official Khronos Group OpenCL headers needed to
compile programs that use OpenCL.

%prep
%autosetup

%build
%cmake
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%doc README.md
%license LICENSE
%dir %{_includedir}/CL
%dir %{_datadir}/cmake/OpenCLHeaders/
%{_datadir}/cmake/OpenCLHeaders/*
%{_datadir}/pkgconfig/OpenCL-Headers.pc
%{_includedir}/CL/*.h*

%changelog
* Mon Nov 25 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2024.10.24:
  * Temporarily disable PPA builds (#267)
  * Update headers regenerated from latest xml (#264)
  * Add properties parameter to all command-buffer commands (#260)
  * Use array for clUpdateMutableCommandsKHR (#245)
  * Disable gcc-11 on MacOS (#262)
  * Update generated headers and remove CL/GL types from cl_platform.h (#257)
  * Fix CI failures (#256)
  * Introduce extension macros (#251)
  * Update CI matrix (#252)
  * Updated CI, added CD (#239)
* Fri Jun  7 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2024.05.08:
  * update extension headers with latest extensions (#249)
  * Fix CMake deprecation warning (#246)
  * cl_mutable_dispatch_asserts_khr definitions (#243)
* Wed Jan 10 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 2023.12.14:
  * updates extension headers for the latest XML file (#244)
  * updates extension headers for the latest XML file (#240)
  * Update extension headers for latest cl.xml changes (#242)
  * add compatibility notes (#238)
  * fix VME skip block type enum to match spec (#241)
  * fix the OpenCL version for the CL_DEPTH enum (#231)
  * require C99 for header tests (#208)
  * sort new extensions programmatically (#236)
  * Update extension headers (#235)
  * Header update for external_memory_import (#234)
  * Define function types for prototype declaration (#230)
* Wed May  3 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 2023.04.17:
  * add headers for cl_khr_command_buffer_multi_device (#229)
  * add code generation README (#228)
  * Code Generation for Extension Headers (#161)
  * Add enum for command-buffer context query (#226)
  * CI Fixes (#225)
  * the pointer argument to clEnqueueWriteHostPipeINTEL should be const (#222)
  * Add cl_intel_program_scope_host_pipe (#220)
  * Install pkgconfig file in CMAKE_INSTALL_DATADIR as headers are architecture independent. (#218)
  * install pkg-config if it is not already installed (#219)
  * cl_loader_layers update (#211)
  * Added support for pkg-config. (#213)
  * Fix CI for MacOS, see https://github.com/KhronosGroup/OpenCL-ICD-Loader/pull/198 . (#215)
  * Revert "Formatted headers and added style check."
  * Formatted headers and added style check.
  * use cinttypes instead of inttypes.h header for C++ tests (#209)
  * Add definitions for cl_arm_scheduling_controls v0.5.0 (#206)
  * Disable anon struct warnings (#200)
  * Definitions for cl_khr_command_buffer_mutable_dispatch (#205)
  * Update cl_ext.h for cl_intel_queue_no_sync_operations (#204)
  * CMakeLists.txt: fix install on macOS if GNU coreutils are used (#203)
  * Update cl_icd.h (#202)
  * Add cl_ext_image_from_buffer extension definition (#196)
  * Add cl_ext_image_requirements_info extension definition (#197)
  * Fix warnings on anonymous structs for MSVC (#198)
  * option to disable tests when subproject (#195)
  * Add cl_intel_mem_alloc_buffer_location property (#193)
  * OpenCL-SDK base changes (#189)
* Wed Dec 29 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20211214:
  * Add definitions for cl_arm_protected_memory_allocation (#187)
* Tue Nov 23 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20211122:
  * update headers for cl_intel_unified_shared_memory (#184)
  * Add provisional command-buffer extension (#182)
  * Rename cl_intel_thread_local_exec to cl_intel_exec_by_local_thread (#183)
  * Fix API suffix version macros for semaphore extensions command definitions (#181)
  * If change the include path destination when run cmake configure with `DCMAKE_INSTALL_INCLUDEDIR`, the .cmake generated still point to hardcoded path `include`. this fix it (#178)
  * add external memory, external semaphore, and semaphore provisional extensions (#180)
  * Fix condition for warning 4201 pop (#179)
  * update extension headers for cl_intel_device_attribute_query (#172)
  * update extension headers for cl_intel_sharing_format_query (#171)
  * Add support for cl_khr_integer_dot_product v2 (#174)
  * update headers for cl_khr_integer_dot_product (#170)
* Mon May 17 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20210426:
  * add cl_khr_pci_bus_info and cl_khr_suggested_local_work_size (#166)
  * Add missing 'stdint.h' include to 'CL/cl.h' (#164)
  * disable failing CI configs (#163)
  * Fixes for usage of macro CL_API_ENTRY (#162)
  * cl_intel_command_queue_families extension (#155)
  * Update default OpenCL version in README (#160)
  * Replace uses of CL_EXT_{PRE,SUF}FIX* with CL_API_{PRE,SUF}FIX* (#158)
  * do not include cl_gl_ext.h from opencl.h (#159)
  * move cl_khr_gl_event to cl_gl.h (#156)
  * Add testing for cl_d3d10.h, cl_d3d11.h, and cl_dx9_media_sharing.h (#123)
  * Add definitions for cl_arm_import_memory_android_hardware_buffer v1.1.0 (#157)
  * Add support for user-supplied prefix/suffix in function declarations (#154)
  * Move cl_icd_layer.h from OpenCL-ICD-Loader to OpenCL-Headers. (#148)
  * Add definitions for cl_arm_controlled_kernel_termination (#152)
  * Add definitions for cl_arm_scheduling_controls v0.3.0 (#151)
  * Remove unused CL_EXTENSION_WEAK_LINK definition (#150)
  * move Intel extensions into common files (#129)
  * Add definitions for cl_arm_scheduling_controls v0.2.0 (#147)
  * Update apt package list in CI before running cmake (#143)
  * re-enable format string warning in CI
  * use PRId64 and PRIu64 when printing 64-bit values
  * fix test format string warnings
  * fix origin argument names for rect functions
  * Enable GitHub Actions for pull requests (#141)
  * Added definitions for cl_img_generate_mipmap. (#135)
  * Added missing define for cl_img_use_gralloc_ptr. (#134)
  * Use the alignment attribute under Integrity OS. (#131)
  * Comprehensive CMake Package Config support (#107)
  * Added definitions for cl_img_mem_properties. (#136)
  * switch the default version for the OpenCL headers to OpenCL 3.0
  * re-enable anonymous unions by default (#125)
  * Avoid anon structs when MSVC uses /Za (#116)
  * update APIs and enums for cl_intel_unified_shared_memory for rev Q (#108)
  * header changes for cl_intel_mem_force_host_memory (#114)
  * Add definitions for cl_ext_cxx_for_opencl (#109)
  * Add definitions for cl_arm_scheduling_controls (#110)
  * Add cl_intel_create_buffer_with_properties and cl_intel_mem_channel_property extensions (#106)
  * add cl_api prefix for clSetContextDestructorCallback
  * update ICD dispatch table with clSetContextDestructorCallback
  * deprecate clSetProgramReleaseCallback
  * add CL_DEVICE_LATEST_CONFORMANCE_VERSION_PASSED
  * add clSetContextDestructorCallback
  * Introduce cl_properties type (#97)
  * switch device enqueue boolean query to capabilities query
  * Fix build of dependent software with clang (#93)
  * add APIs and enums for cl_intel_unified_shared_memory (#65)
  * Add cl_khr_device_uuid definitions (#91)
* Wed May 27 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20200512:
  * Add cl_half.h header (#60)
  * add tokens for cl_amd_device_attribute_query (#90)
  * Add Windows CI using Travis (#82)
  * update headers for OpenCL 3.0 (#88)
  * Add cl_khr_extended_versioning macro (#85)
  * Synchronize experimental enum etc with cl.xml (#83)
  * Include the DirectX sharing headers from CL/cl_icd.h. (#81)
  * add missing error code CL_CONTEXT_TERMINATED_KHR
  * Change license to Apache 2.0 (#76)
  * Add enum value for `cl_khronos_vendor_id` (#71)
  * Experimental enum cl_khronos_vendor_id (#75)
  * experimental enums for language queries
  * add experimental enum CL_COMMAND_SVM_MIGRATE_MEM
  * move two subgroup queries from cl_kernel_info to cl_kernel_sub_group_info
* Fri Feb 28 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20200218:
  * add experimental enums (#70)
  * Add CL_IMPORT_DMA_BUF_DATA_CONSISTENCY_WITH_HOST_ARM definition (#72)
  * Add tests and Travis CI config (#64)
  * Add definitions for cl_arm_import_memory_android_hardware_buffer (#61)
  * Add version guards to ICD declarations (#63)
  * Add cl_khr_extended_versioning definitions (#59)
  * Add API function pointer and ICD dispatch table definitions (#50)
* Tue Aug 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20190806:
  * Add definitions for cl_arm_job_slot_selection (#52)
  * Fix _cl_image_desc for OpenCL 1.2 compatibility
  * Simplify the definition of deprecation prefixes/suffixes (#45)
  * added suffixed enums for cl_khr_image2d_from_buffer
  * drop __attribute__((aligned(X))) from cl_X defs
  * small typo fix for pfn_notify
  * removing comments around arguments:
  * Use __vector instead of vector to fix altivec builds
  * Fix clCreateFromGLBuffer error code result type
* Fri Jan 11 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.2+git.20181211:
  * Fixed w4201 triggering with MSVC in /W4 /Za builds
  * add suffixed enums for cl_khr_mipmap_image
  * Remove all Apple specific content from headers
  * Create CODE_OF_CONDUCT.md
  * Add enums for cl_arm_get_core_id
  * Rename CL_IMPORT_TYPE_SECURE_ARM
  * Add CL_DEVICE_DOUBLE_FP_CONFIG
  * remove CL_DEVICE_HALF_FP_CONFIG
  * added clSetCommandQueueProperty to unified headers
  * Unified Headers
  * Added following Qualcomm extensions:
  * Add cl_khr_il_program to OpenCL 1.2 and 2.0 headers
  * added cl_khr_create_command_queue
  * Use correctly rounded decimal mathematical constants
  * Shorten CL_DBL_MAX for Visual Studio to fix token overflow
  * Anon structs supported in C11
  * add LICENSE file
* Tue Jun 20 2017 mpluskal@suse.com
- Update to version 2.2+git.20170617:
  * Bug 14749 - Incorrect clGetKernelSubGroupInfoKHR typedef in cl_ext.h
  * Remove C++ headers from repository
  * Update to March 2015 Khronos Free Use License
  * Remove unneeded EGL includes from cl_egl.h
  * Add snapshot of OpenCL 1.2 headers
  * Update to March 2015 Khronos Free Use License
  * Remove unneeded EGL includes from cl_egl.h
  * Add snapshot of OpenCL 1.1 headers
  * Update to March 2015 Khronos Free Use License
  * Add snapshot of OpenCL 1.0 headers
  * Update to March 2015 Khronos Free Use License
  * added CL_DEVICE_HALF_FP_CONFIG define
  * added CL_DEVICE_HALF_FP_CONFIG define
  * Fix gcc -Wundef warning
  * cl_halfn declarations
  * Fix gcc -Wundef warning
  * cl_halfn declarations
  * added headers for Intel vendor extensions
  * added headers for Intel vendor extensions
  * Add tokens for cl_img_use_gralloc_ptr, cl_img_cached_allocations and  cl_img_yuv_image extensions (#13)
  * Add tokens for cl_img_use_gralloc_ptr, cl_img_cached_allocations and  cl_img_yuv_image extensions (#13)
  * adding half defines to cl_platform.h
  * adding cl_arm_shared_virtual_memory extension
  * adding cl_arm_import_memory extension
  * adding half defines to cl_platform.h
  * adding cl_arm_import_memory extension
  * adding cl_arm_shared_virtual_memory extension
  * initial OpenCL 2.2 headers commit
  * added clSetProgramReleaseCallback and CL_INVALID_SPEC_ID
  * slightly more accurate CL_FLT_EPSILON
  * OpenCL 2.0 CL_FLT_EPSILON fix
  * OpenCL 1.2 CL_FLT_EPSILON fix
  * OpenCL 1.1 CL_FLT_EPSILON fix
  * OpenCL 1.0 CL_FLT_EPSILON fix
  * added CL_MAX_SIZE_RESTRICTION_EXCEEDED error code
  * Replace hexdecimal fp constants with decimal fp constants
  * Replace hexdecimal fp constants with decimal fp constants
  * Replace hexdecimal fp constants with decimal fp constants
  * Replace hexdecimal fp constants with decimal fp constants
  * Replace hexdecimal fp constants with decimal fp constants
  * header updates for cl_intel_planar_yuv header updates for cl_intel_device_side_avc_motion_estimation
  * header updates for cl_intel_planar_yuv header updates for cl_intel_device_side_avc_motion_estimation
  * header updates for cl_intel_planar_yuv header updates for cl_intel_device_side_avc_motion_estimation
  * Fix -Wundef warning under Ubuntu 14.04
  * Fix -Wundef warning under Ubuntu 14.04
  * Fix -Wundef warning under Ubuntu 14.04
  * Move 2.1 headers to opencl21/
  * cl_khr_sub_group_named_barrier -> cl_khr_subgroup_named_barrier
  * Remove duplicate ARM extension definition
  * Renamed cl_khr_sub_groups -> cl_khr_subgroups to be consistent with the spec
  * Move OpenCL 1.0 headers to opencl10/CL
  * Move OpenCL 1.1 headers to opencl11/CL
  * Move OpenCL 1.2 headers to opencl12/CL
  * Move OpenCL 2.0 headers to opencl20/CL
  * Move OpenCL 2.1 headers to opencl21/CL
  * Move OpenCL 2.2 headers to opencl22/CL
  * Fix typo in comment
* Thu Feb 16 2017 mpluskal@suse.com
- Update to version 2.2+git.20170213:
  * adding half defines to cl_platform.h
  * adding cl_arm_import_memory extension
  * adding cl_arm_shared_virtual_memory extension
  * OpenCL 2.1 CL_FLT_EPSILON fix
  * Replace hexdecimal fp constants with decimal fp constants
  * header updates for cl_intel_planar_yuv header updates for cl_intel_device_side_avc_motion_estimation
  * Fix -Wundef warning under Ubuntu 14.04
* Thu Nov 24 2016 mpluskal@suse.com
- Update to version 2.2+git.20161018:
  * added CL_DEVICE_HALF_FP_CONFIG define
  * Fix gcc -Wundef warning
  * cl_halfn declarations
  * added headers for Intel vendor extensions
  * Add tokens for cl_img_use_gralloc_ptr, cl_img_cached_allocations and  cl_img_yuv_image extensions (#13)
* Thu Jun 30 2016 mpluskal@suse.com
- Update to version 2.2+git.20160614:
  * Append _khr suffix to cl_kernel_sub_group_info typedef in cl_ext.h
  * Mark clGetKernelSubGroupInfoKHR as deprecated
* Tue Apr 19 2016 mpluskal@suse.com
- Update to 2.1+git.20160105
- Use _service instead of get-tarball.sh
* Sat Nov 21 2015 mpluskal@suse.com
- Update to 2.1_20151117
  * No changelog available
- Tiny spec file cleanup
* Sat Jun 13 2015 dmitry_r@opensuse.org
- Update to version 2.0_20141118
  * No changelog available
* Sat Jun 13 2015 dmitry_r@opensuse.org
- Update to version 1.2_20150303
  * No changelog available
- Use full version number
* Wed May  1 2013 prusnak@opensuse.org
- created package (version 1.2-20130212)
